##  Accessing Linked Collibra Entities
You can quickly access linked Collibra entitties directly from the fact sheets in SAP LeanIX. This allows you to easily reference related information while working in SAP LeanIX. To access the linked item, click on the Collibrta external ID in the Name & Description section of the fact sheet, or on the right-side panel, click on Collibra under the Integrations section.
**Note**
To learn about collibraExternalId field in the fact sheet, see [Mapping Fields](https://help.sap.com/docs/leanix/ea/conceptual-data-layer-mapping-from-collibra-to-sap-leanix?locale=en-US&state=PRODUCTION&version=CLOUD#loio2759424d7a441014ba33feeaa45a67d4__mapping_fields).
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274af1997a441014a2eec71ed9e9c955_LowRes.png)
You can also find the link in the resources tab of the fact sheets. The resource backlink is updated in the fact sheet only in the following sync run once the fact sheet has been successfully mapped to Collibra in the previous sync run.
